clear all
%close all
clc

disp('============================================================');
disp('=                 Anlise de dados                         =');
disp('=            PNV3391 Laboratrio de Engenharia Naval       =');
disp('=           Prof Dr Gustavo Assi - EPUSP                   =');
disp('=                g.assi@usp.br                             =');
disp('============================================================');


%% Definies das janelas

% define communication window
main_win = figure('name','Summary',...
    'units','normalized',...
    'position',[.05 .1 .8 .8]);

% divide main_win
disp_win = subplot('position',[0.05 0.7 0.9 0.20]);
axis off
rectangle('facecolor','w')

Fy_d_win = subplot('position',[0.05 0.4 0.9 0.20]);
axis off
rectangle('facecolor','w')

psd_win = subplot('Position',[0.05 0.05 0.9 0.25]);
axis off
rectangle('facecolor','w')


%% Variveis de controle



%% Ler arquivo de dados
[Filename,Path] = uigetfile('*.dat','Choose DATA file:');
Filename




%% Monta matriz de dados (para no alterar aquivo de origem)
A = load(Filename);

   A(10000:end,:) = [];

N = length(A);

%% Extrai cada uma das variveis da matriz
t = A(:,1);         % tempo
y = A(:,2);         % [mm] Deslocamento 
Fy = -A(:,3);       % [N] Fora da celula de carga



%% Calcula alguns parmetros
% D = 0.06 %[m]
% Re=U*D*1000000
% Fr = 


%% Parmetros da aquisicao
dt = (t(2)-t(1));
Faq = 1/dt;       % Freq de aquisicao [Hz]
Taq = t(end)+t(2);         % Tempo total de aquisicao


%% Plota dados originais
figure(main_win)

subplot(disp_win)
plot(t,y,'b');
hold on
xlabel('Tempo [s]')
ylabel('y [mm]')


subplot(Fy_d_win)
plot(t,Fy,'r');
hold on
xlabel('Tempo [s]')
ylabel('F [N]')


%%
%%%%%%%%%%%%%%%%%%%%%%%% ANLISE ESPECTRAL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Determina a frequencia dominante no sinal

NFFT = 2^nextpow2(N); % Next power of 2 from length of y

YY = fft(y,NFFT)/N;
PSD_y = 2*abs(YY(1:NFFT/2+1));
f_y = Faq/2*linspace(0,1,NFFT/2+1);
[YYmax,Ind] = max(PSD_y(1:end));
fd_y = f_y(Ind)   % Dominant frequency

FF = fft(Fy,NFFT)/N;
PSD_F = 2*abs(FF(1:NFFT/2+1));
f_F = Faq/2*linspace(0,1,NFFT/2+1);
[FFmax,Ind] = max(PSD_F(1:end));
fd_F = f_F(Ind)   % Dominant frequency



% plot
figure(main_win)
subplot(psd_win)

plot(f_y,PSD_y,'b') 
hold on
plot(f_F,PSD_F,'r') 

grid on
axis([0 5 -inf inf]);
title('Power Spectral Density')
xlabel('Frequencia [Hz]')
 text(fd_y,YYmax,...
    ['fd_y = ',num2str(fd_y,'%2.2f'),' [Hz]'])
 set(gca,'YScale','log')



% %% 
% % %%%%%%%%%%%%%%%%%%%%%%%% FILTER SIGNALS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % % General Butterworth filter parameters
% % cutoff_freq = 5;   % [Hz] cutoff frequency for low-pass filter
% % order = 2;         % Butterwoth filter order
% % [filt_b,filt_a] = butter(order,cutoff_freq/(Faq/2)); % filter parameters
% % 
% % % Apply filter to signals
% % y = filter(filt_b,filt_a,y);
% % %%%%%%%%%%%%%%%%%%%%%%%% FILTER SIGNALS end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%
%%%%%%%%%%%%%%%%%%%%%%%% Envelope do sinal %%%%%%%%%%%%%%%
Zy = hilbert(y);   % Analytical signal of displacement signal
Env_y = abs(Zy);  % Envelope of signals: Absolute value of the analytical signals


figure(main_win)
subplot(disp_win)
hold on
plot(t,Env_y,'k')

Env_y_mean = mean(Env_y)
%%%%%%%%%%%%%%%%%%%%%%%% Envelope do sinal %%%%%%%%%%%%%%%



